#include <esp_now.h>
#include "esp_wifi.h"
#include <WiFi.h>

uint8_t myData[250];
bool sendDone = true;
uint32_t cnt, max_cnt = 5000;
uint8_t targetMAC[] = { 0xF4, 0x12, 0xFA, 0x43, 0x36, 0x30 };
// 回调函数,函数将在发送消息时执行。此函数告诉我们信息是否成功发送;
void OnDataSent(const uint8_t *mac_addr, esp_now_send_status_t status) {
  if (status != ESP_NOW_SEND_SUCCESS) {
    Serial.println("Send Fail");
    if (cnt > 0) {
      cnt--;
    }
  }
  sendDone = true;
}

void setup() {
  // 初始化串口波特率
  Serial.begin(115200);
  // 设置WIFI模式为STA模式，即无线终端
  WiFi.mode(WIFI_AP);
  // config ESPNOW rate
  esp_wifi_config_espnow_rate(WIFI_IF_AP, WIFI_PHY_RATE_MCS7_SGI);
  //  初始化ESP-NOW
  if (esp_now_init() != ESP_OK) {
    Serial.println("Error initializing ESP-NOW");
    return;
  }
  //注册回调函数
  esp_now_register_send_cb(OnDataSent);
  // 注册通信频道
  esp_now_peer_info_t peerInfo;
  memcpy(peerInfo.peer_addr, targetMAC, 6);
  peerInfo.channel = 0;      //通道
  peerInfo.encrypt = false;  //是否加密为False
  peerInfo.ifidx = WIFI_IF_AP;
  if (esp_now_add_peer(&peerInfo) != ESP_OK) {
    Serial.println("Failed to add peer");
    return;
  }
  int8_t pw;
  esp_wifi_get_max_tx_power(&pw);
  Serial.println("Power:"+String(pw));
}

esp_err_t result;
unsigned long startTime, deltaTime = 0;
bool startcnt = true;
void loop() {
  if (startcnt) {
    startcnt = false;
    startTime = micros();
    Serial.printf("startTime:%ld", startTime);
    Serial.println();
  }
  if (sendDone && cnt < max_cnt) {
    sendDone = false;
    //发送信息到指定ESP32上
    result = esp_now_send(targetMAC, myData, sizeof(myData));
    if (result != ESP_OK) {
      sendDone = true;
      if (cnt > 0) {
        cnt--;
      }
      Serial.println("Error sending the data");
    }
    cnt++;
  }
  if (max_cnt == cnt) {
    deltaTime = micros() - startTime;
    Serial.printf("deltaTime:%ld", deltaTime);
    Serial.println();
    cnt++;
  }
}
